@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.115-8-g7c1193c
+package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.116-5-g4b81f4d
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: A plugin bundle for distributions built by ETHER
 # KEYWORDS: author bundle distribution tool
 
-our $VERSION = '0.116';
+our $VERSION = '0.117';
 
 use Moose;
 with
@@ -29,9 +29,16 @@ sub mvp_multivalue_args { qw(installer copy_file_from_release) }
 # but [PromptIfStale] generally makes that unnecessary
 has installer => (
     isa => 'ArrayRef[Str]',
+    init_arg => undef,
     lazy => 1,
     default => sub {
-        $_[0]->payload->{installer} // [ 'MakeMaker::Fallback', 'ModuleBuildTiny::Fallback' ];
+        my $self = shift;
+
+        return [ 'MakeMaker::Fallback', 'ModuleBuildTiny::Fallback' ]
+            if not exists $self->payload->{installer};
+
+        # remove 'none' from installer list
+        return [ grep { $_ ne 'none' } @{ $self->payload->{installer} } ];
     },
     traits => ['Array'],
     handles => { installer => 'elements' },
@@ -39,24 +46,28 @@ has installer => (
 
 has server => (
     is => 'ro', isa => enum([qw(github gitmo p5sagit catagits none)]),
+    init_arg => undef,
     lazy => 1,
     default => sub { $_[0]->payload->{server} // 'github' },
 );
 
 has surgical_podweaver => (
     is => 'ro', isa => 'Bool',
+    init_arg => undef,
     lazy => 1,
     default => sub { $_[0]->payload->{surgical_podweaver} // 0 },
 );
 
 has airplane => (
     is => 'ro', isa => 'Bool',
+    init_arg => undef,
     lazy => 1,
     default => sub { $ENV{DZIL_AIRPLANE} || $_[0]->payload->{airplane} // 0 },
 );
 
 has copy_file_from_release => (
     isa => 'ArrayRef[Str]',
+    init_arg => undef,
     lazy => 1,
     default => sub { $_[0]->payload->{copy_file_from_release} // [] },
     traits => ['Array'],
@@ -70,16 +81,18 @@ around copy_files_from_release => sub {
 
 has changes_version_columns => (
     is => 'ro', isa => subtype('Int', where { $_ > 0 && $_ < 20 }),
+    init_arg => undef,
     lazy => 1,
     default => sub { $_[0]->payload->{changes_version_columns} // 10 },
 );
 
 has licence => (
     is => 'ro', isa => 'Str',
+    init_arg => undef,
     lazy => 1,
     default => sub {
         my $self = shift;
-        my $authority = $self->payload->{'Authority.authority'} // 'cpan:ETHER';
+        my $authority = $self->authority;
         $self->payload->{licence}
             // $self->payload->{license}
             # licenSe is US-only; known non-American authors will be treated appropriately.
@@ -88,6 +101,22 @@ has licence => (
     },
 );
 
+has authority => (
+    is => 'ro', isa => 'Str',
+    init_arg => undef,
+    lazy => 1,
+    default => sub {
+        my $self = shift;
+
+        # we could warn about this, but then we'd have to change configs (and bump prereqs) for an awful lot of
+        # distributions.
+        return $self->payload->{'Authority.authority'}
+            if exists $self->payload->{'Authority.authority'};
+
+        $self->payload->{authority} // 'cpan:ETHER';
+    },
+);
+
 # configs are applied when plugins match ->isa($key) or ->does($key)
 my %extra_args = (
     'Dist::Zilla::Plugin::MakeMaker' => { 'eumm_version' => '0' },
@@ -127,18 +156,6 @@ my @never_gather = qw(
     inc/ExtUtils/MakeMaker/Dist/Zilla/Develop.pm
 );
 
-around BUILDARGS => sub
-{
-    my $orig = shift;
-    my $self = shift;
-    my $args = $self->$orig(@_);
-
-    # remove 'none' from installer list
-    return $args if not exists $args->{payload}{installer};
-    @{$args->{payload}{installer}} = grep { $_ ne 'none' } @{$args->{payload}{installer}};
-    return $args;
-};
-
 sub configure
 {
     my $self = shift;
@@ -181,7 +198,7 @@ sub configure
     # only set x_static_install using auto mode for my own distributions
     my $static_install_mode = $self->payload->{'StaticInstall.mode'} // 'auto';
     my $static_install_dry_run = ($static_install_mode eq 'auto'
-            and ($self->payload->{'Authority.authority'} // 'cpan:ETHER') ne 'cpan:ETHER') ? 1 : 0;
+            and $self->authority ne 'cpan:ETHER') ? 1 : 0;
 
     warn '[@Author::ETHER] ', colored('server = ' . $self->server
             . ': recommend instead using server = github and GithubMeta.remote = '
@@ -228,7 +245,7 @@ sub configure
         [ 'Test::NoTabs'        => { ':version' => '0.08', finder => [qw(:InstallModules :ExecFiles @Author::ETHER/Examples :TestFiles :ExtraTestFiles)] } ],
         [ 'Test::EOL'           => { ':version' => '0.17', finder => [qw(:InstallModules :ExecFiles @Author::ETHER/Examples :TestFiles :ExtraTestFiles)] } ],
         'MetaTests',
-        [ 'Test::CPAN::Changes' => { ':version' => '0.008' } ],
+        [ 'Test::CPAN::Changes' => { ':version' => '0.012' } ],
         'Test::ChangesHasContent',
         [ 'Test::MinimumVersion' => { ':version' => '2.000003', max_target_perl => '5.006' } ],
         [ 'PodSyntaxTests'      => { ':version' => '5.040' } ],
@@ -265,7 +282,7 @@ sub configure
             : $self->server eq 'catagits' ? ( 'repository.catagits' => 1 )
             : ()
         } ],
-        [ 'Authority'           => { ':version' => '1.009', authority => 'cpan:ETHER', do_munging => 0 } ],
+        [ 'Authority'           => { ':version' => '1.009', authority => $self->authority, do_munging => 0 } ],
         [ 'MetaNoIndex'         => { directory => [ qw(t xt), grep { -d } qw(inc local perl5 fatlib examples share corpus demo) ] } ],
         [ 'MetaProvides::Package' => { ':version' => '1.15000002', finder => ':InstallModules', meta_noindex => 1, inherit_version => 0, inherit_missing => 0 } ],
         'MetaConfig',
@@ -456,7 +473,7 @@ Dist::Zilla::PluginBundle::Author::ETHER - A plugin bundle for distributions bui
 
 =head1 VERSION
 
-version 0.116
+version 0.117
 
 =head1 SYNOPSIS
 
@@ -556,7 +573,7 @@ following F<dist.ini> (following the preamble), minus some optimizations:
 
     [MetaTests]
     [Test::CPAN::Changes]
-    :version = 0.008
+    :version = 0.012
     [Test::ChangesHasContent]
     [Test::MinimumVersion]
     :version = 2.000003
@@ -983,6 +1000,16 @@ C<LICENCE> for distributions where I (ETHER) or any other known non-Americans
 have first-come permissions, or C<LICENSE> otherwise.
 (The pod section for legal information is also adjusted appropriately.)
 
+=head2 authority
+
+Available since 0.117.
+
+A string of the form C<cpan:PAUSEID> that references the PAUSE ID of the user who has primary ("first-come")
+authority over the distribution and main module namespace. If not provided, it is extracted from the configuration
+passed through to the <[Authority]|Dist::Zilla::Plugin::Authority> plugin, and finally defaults to C<cpan:ETHER>.
+It is presently used for setting C<x_authority> metadata and deciding which spelling is used for the F<LICENCE>
+file (if the C<licence> configuration is not provided).
+
 =for stopwords customizations
 
 =head2 other customizations
